@@ -10,7 +10,8 @@ class MainConfig:
     should need to be changed
     """
 
-
+    # the version information of the server (recommended to leave as default)
+    version = 'FreeTAKServer-1.9.2.5 Alpha RC 1'
     #
     yaml_path = str(os.environ.get('FTS_CONFIG_PATH', '/opt/FTSConfig.yaml'))
 
@@ -102,6 +103,11 @@ class MainConfig:
 
         CRLFile = str(os.environ.get('FTS_CRLDIR', fr"{certsPath}/FTS_CRL.json"))
 
+        # set to None if you don't want a message sent
+        ConnectionMessage = f'Welcome to FreeTAKServer {version}. The Parrot is not dead. It’s just resting'
+
+        DataBaseType = str("SQLite")
+
     else:
         content = open(yaml_path).read()
         yamlConfig = yaml.safe_load(content)
@@ -110,29 +116,34 @@ class MainConfig:
         # decreasing will increase CPU usage and server performance
         # increasing will decrease CPU usage and server performance
         if yamlConfig.get("System"):
-            MainLoopDelay = int(os.environ.get('FTS_MAINLOOP_DELAY', yamlConfig["System"].get("MainLoopDelay", 1)))
+            MainLoopDelay = int(os.environ.get('FTS_MAINLOOP_DELAY', yamlConfig["System"].get("FTS_MAINLOOP_DELAY", 1)))
+            # set to None if you don't want a message sent
+            ConnectionMessage = str(os.environ.get("FTS_CONNECTION_MESSAGE", yamlConfig["System"].get("FTS_CONNECTION_MESSAGE", f'Welcome to FreeTAKServer {version}. The Parrot is not dead. It’s just resting')))
+            DataBaseType = str(os.environ.get("FTS_DATABASE_TYPE", yamlConfig["System"].get("FTS_DATABASE_TYPE", "SQLite")))
         else:
             MainLoopDelay = int(os.environ.get('FTS_MAINLOOP_DELAY',  1))
+            ConnectionMessage = str(os.environ.get("FTS_CONNECTION_MESSAGE", f'Welcome to FreeTAKServer {version}. The Parrot is not dead. It’s just resting'))
+            DataBaseType = str(os.environ.get("FTS_DATABASE_TYPE", "SQLite"))
         if yamlConfig.get("Addresses"):
             # this is the port to which clients will connect
-            CoTServicePort = int(os.environ.get('FTS_COT_PORT', yamlConfig["Addresses"].get('CoTServicePort', 8087)))
+            CoTServicePort = int(os.environ.get('FTS_COT_PORT', yamlConfig["Addresses"].get('FTS_COT_PORT', 8087)))
 
-            SSLCoTServicePort = int(os.environ.get('FTS_SSLCOT_PORT', yamlConfig["Addresses"].get('SSLCoTServicePort', 8089)))
+            SSLCoTServicePort = int(os.environ.get('FTS_SSLCOT_PORT', yamlConfig["Addresses"].get('FTS_SSLCOT_PORT', 8089)))
 
             # this needs to be changed for private data packages to work
-            DataPackageServiceDefaultIP = str(os.environ.get('FTS_DP_ADDRESS', yamlConfig["Addresses"].get('DataPackageServiceDefaultIP', ip)))
+            DataPackageServiceDefaultIP = str(os.environ.get('FTS_DP_ADDRESS', yamlConfig["Addresses"].get('FTS_DP_ADDRESS', ip)))
 
             # User Connection package IP needs to be set to the IP which is used when creating the connection in your tak device
-            UserConnectionIP = str(os.environ.get('FTS_USER_ADDRESS', yamlConfig["Addresses"].get("UserConnectionIP", ip)))
+            UserConnectionIP = str(os.environ.get('FTS_USER_ADDRESS', yamlConfig["Addresses"].get("FTS_USER_ADDRESS", ip)))
 
             # api port
-            APIPort = int(os.environ.get('FTS_API_PORT', yamlConfig["Addresses"].get("APIPort", 19023)))
+            APIPort = int(os.environ.get('FTS_API_PORT', yamlConfig["Addresses"].get("FTS_API_PORT", 19023)))
 
             # Federation port
-            FederationPort = int(os.environ.get('FTS_FED_PORT', yamlConfig["Addresses"].get("FederationPort", 9000)))
+            FederationPort = int(os.environ.get('FTS_FED_PORT', yamlConfig["Addresses"].get("FTS_FED_PORT", 9000)))
 
             # api IP
-            APIIP = str(os.environ.get('FTS_API_ADDRESS', yamlConfig["Addresses"].get("APIIP", "0.0.0.0")))
+            APIIP = str(os.environ.get('FTS_API_ADDRESS', yamlConfig["Addresses"].get("FTS_API_ADDRESS", "0.0.0.0")))
         else:
 
             # this is the port to which clients will connect
@@ -157,24 +168,24 @@ class MainConfig:
 
         if yamlConfig.get("FileSystem"):
 
-            DBFilePath = str(os.environ.get('FTS_DB_PATH', yamlConfig["FileSystem"].get("DBFilePath", "/opt/FreeTAKServer")))
+            DBFilePath = str(os.environ.get('FTS_DB_PATH', yamlConfig["FileSystem"].get("FTS_DB_PATH", "/opt/FreeTAKServer.db")))
 
             # whether or not to save CoT's to the DB
-            SaveCoTToDB = bool(os.environ.get('FTS_COT_TO_DB', yamlConfig["FileSystem"].get("SaveCoTToDB")))
+            SaveCoTToDB = bool(os.environ.get('FTS_COT_TO_DB', yamlConfig["FileSystem"].get("FTS_COT_TO_DB")))
 
-            MainPath = str(os.environ.get("FTS_MAINPATH", yamlConfig["FileSystem"].get("MainPath", Path(fr'{userpath}{python_version}/dist-packages/FreeTAKServer'))))
+            MainPath = str(os.environ.get("FTS_MAINPATH", yamlConfig["FileSystem"].get("FTS_MAINPATH", Path(fr'{userpath}{python_version}/dist-packages/FreeTAKServer'))))
 
-            certsPath = str(os.environ.get('FTS_CERTS_PATH', yamlConfig["FileSystem"].get("CertsPath", fr'{MainPath}/certs')))
+            certsPath = str(os.environ.get('FTS_CERTS_PATH', yamlConfig["FileSystem"].get("FTS_CERTS_PATH", fr'{MainPath}/certs')))
 
-            ExCheckMainPath = str(os.environ.get('FTS_EXCHECK_PATH', yamlConfig["FileSystem"].get("ExCheckPath",Path(fr'{MainPath}/ExCheck'))))
+            ExCheckMainPath = str(os.environ.get('FTS_EXCHECK_PATH', yamlConfig["FileSystem"].get("FTS_EXCHECK_PATH",Path(fr'{MainPath}/ExCheck'))))
 
-            ExCheckFilePath = str(os.environ.get('FTS_EXCHECK_TEMPLATE_PATH', yamlConfig["FileSystem"].get("ExCheckTemplatePath", Path(fr'{MainPath}/ExCheck/template'))))
+            ExCheckFilePath = str(os.environ.get('FTS_EXCHECK_TEMPLATE_PATH', yamlConfig["FileSystem"].get("FTS_EXCHECK_TEMPLATE_PATH", Path(fr'{MainPath}/ExCheck/template'))))
 
-            ExCheckChecklistFilePath = str(os.environ.get("FTS_EXCHECK_CHECKLIST_PATH", yamlConfig["FileSystem"].get("ExCheckChecklistPath", Path(fr'{MainPath}/ExCheck/checklist'))))
+            ExCheckChecklistFilePath = str(os.environ.get("FTS_EXCHECK_CHECKLIST_PATH", yamlConfig["FileSystem"].get("FTS_EXCHECK_CHECKLIST_PATH", Path(fr'{MainPath}/ExCheck/checklist'))))
 
-            DataPackageFilePath = str(os.environ.get("FTS_DATAPACKAGE_PATH", yamlConfig["FileSystem"].get("DataPackageFilePath", Path(fr'{MainPath}/FreeTAKServerDataPackageFolder'))))
+            DataPackageFilePath = str(os.environ.get("FTS_DATAPACKAGE_PATH", yamlConfig["FileSystem"].get("FTS_DATAPACKAGE_PATH", Path(fr'{MainPath}/FreeTAKServerDataPackageFolder'))))
 
-            LogFilePath = str(os.environ.get("FTS_LOGFILE_PATH", yamlConfig["FileSystem"].get("LogFilePath", Path(fr"{MainPath}/Logs"))))
+            LogFilePath = str(os.environ.get("FTS_LOGFILE_PATH", yamlConfig["FileSystem"].get("FTS_LOGFILE_PATH", Path(fr"{MainPath}/Logs"))))
 
         else:
             # whether or not to save CoT's to the DB
@@ -202,33 +213,33 @@ class MainConfig:
 
 
         if yamlConfig.get("Certs"):
-            keyDir = str(os.environ.get("FTS_SERVER_KEYDIR", yamlConfig["Certs"].get("ServerKeyDir", Path(fr'{certsPath}/server.key'))))
+            keyDir = str(os.environ.get("FTS_SERVER_KEYDIR", yamlConfig["Certs"].get("FTS_SERVER_KEYDIR", Path(fr'{certsPath}/server.key'))))
 
-            pemDir = str(os.environ.get("FTS_SERVER_PEMDIR",yamlConfig["Certs"].get("ServerPemDir", Path(fr'{certsPath}/server.pem')))) # or crt
+            pemDir = str(os.environ.get("FTS_SERVER_PEMDIR",yamlConfig["Certs"].get("FTS_SERVER_PEMDIR", Path(fr'{certsPath}/server.pem')))) # or crt
 
-            testPem = str(os.environ.get("FTS_TESTCLIENT_PEMDIR",yamlConfig["Certs"].get("TestPemDir", fr'{certsPath}/Client.pem')))
+            testPem = str(os.environ.get("FTS_TESTCLIENT_PEMDIR",yamlConfig["Certs"].get("FTS_TESTCLIENT_PEMDIR", fr'{certsPath}/Client.pem')))
 
-            testKey = str(os.environ.get("FTS_TESTCLIENT_KEYDIR",yamlConfig["Certs"].get("TestKeyDir", fr'{certsPath}/Client.key')))
+            testKey = str(os.environ.get("FTS_TESTCLIENT_KEYDIR",yamlConfig["Certs"].get("FTS_TESTCLIENT_KEYDIR", fr'{certsPath}/Client.key')))
 
-            unencryptedKey = str(os.environ.get("FTS_UNENCRYPTED_KEYDIR", yamlConfig["Certs"].get("UnencryptedKeyDir", Path(fr'{certsPath}/server.key.unencrypted'))))
+            unencryptedKey = str(os.environ.get("FTS_UNENCRYPTED_KEYDIR", yamlConfig["Certs"].get("FTS_UNENCRYPTED_KEYDIR", Path(fr'{certsPath}/server.key.unencrypted'))))
 
-            p12Dir = str(os.environ.get("FTS_SERVER_P12DIR", yamlConfig["Certs"].get("ServerP12Dir", Path(fr'{certsPath}/server.p12'))))
+            p12Dir = str(os.environ.get("FTS_SERVER_P12DIR", yamlConfig["Certs"].get("FTS_SERVER_P12DIR", Path(fr'{certsPath}/server.p12'))))
 
-            CA = str(os.environ.get("FTS_CADIR", yamlConfig["Certs"].get("CAPemDir",Path(fr'{certsPath}/ca.pem'))))
+            CA = str(os.environ.get("FTS_CADIR", yamlConfig["Certs"].get("FTS_CADIR",Path(fr'{certsPath}/ca.pem'))))
 
-            CAkey = str(os.environ.get("FTS_CAKEYDIR", yamlConfig["Certs"].get("CAKeyDir",Path(fr'{certsPath}/ca.key'))))
+            CAkey = str(os.environ.get("FTS_CAKEYDIR", yamlConfig["Certs"].get("FTS_CAKEYDIR",Path(fr'{certsPath}/ca.key'))))
 
-            federationCert = str(os.environ.get("FTS_FEDERATION_CERTDIR", yamlConfig["Certs"].get("FederationPemDir", Path(fr'{certsPath}/server.pem'))))
+            federationCert = str(os.environ.get("FTS_FEDERATION_CERTDIR", yamlConfig["Certs"].get("FTS_FEDERATION_CERTDIR", Path(fr'{certsPath}/server.pem'))))
 
-            federationKey = str(os.environ.get("FTS_FEDERATION_KEYDIR", yamlConfig["Certs"].get("FederationKeyDir", Path(fr'{certsPath}/server.key'))))
+            federationKey = str(os.environ.get("FTS_FEDERATION_KEYDIR", yamlConfig["Certs"].get("FTS_FEDERATION_KEYDIR", Path(fr'{certsPath}/server.key'))))
 
-            federationKeyPassword = str(os.environ.get("FTS_FEDERATION_KEYPASS", yamlConfig["Certs"].get("FederationKeyPassword", None)))
+            federationKeyPassword = str(os.environ.get("FTS_FEDERATION_KEYPASS", yamlConfig["Certs"].get("FTS_FEDERATION_KEYPASS", None)))
 
-            password = str(os.environ.get('FTS_CLIENT_CERT_PASSWORD', yamlConfig["Certs"].get("ClientCertPassword", 'defaultpass')))
+            password = str(os.environ.get('FTS_CLIENT_CERT_PASSWORD', yamlConfig["Certs"].get("FTS_CLIENT_CERT_PASSWORD", 'supersecret')))
 
-            websocketkey = str(os.environ.get('FTS_WEBSOCKET_KEY', yamlConfig["Certs"].get("WebsocketKey", "YourWebsocketKey")))
+            websocketkey = str(os.environ.get('FTS_WEBSOCKET_KEY', yamlConfig["Certs"].get("FTS_WEBSOCKET_KEY", "YourWebsocketKey")))
 
-            CRLFile = str(os.environ.get('FTS_CRLDIR', yamlConfig["Certs"].get("CRLDir", fr"{certsPath}/FTS_CRL.json")))
+            CRLFile = str(os.environ.get('FTS_CRLDIR', yamlConfig["Certs"].get("FTS_CRLDIR", fr"{certsPath}/FTS_CRL.json")))
         else:
             federationKeyPassword = str(os.environ.get('FTS_FED_PASSWORD', 'defaultpass'))
 
@@ -254,15 +265,13 @@ class MainConfig:
 
             federationKeyPassword = str(os.environ.get("FTS_FEDERATION_KEYPASS", 'defaultpass'))
 
-            password = str(os.environ.get('FTS_CLIENT_CERT_PASSWORD', 'defaultpass'))
+            password = str(os.environ.get('FTS_CLIENT_CERT_PASSWORD', 'supersecret'))
 
             websocketkey = str(os.environ.get('FTS_WEBSOCKET_KEY', "YourWebsocketKey"))
 
             CRLFile = str(os.environ.get('FTS_CRLDIR', fr"{certsPath}/FTS_CRL.json"))
 
 
-    # the version information of the server (recommended to leave as default)
-    version = 'FreeTAKServer-1.9 Alpha RC 2'
 
     # allowed ip's to access CLI commands
     AllowedCLIIPs = ['127.0.0.1']
@@ -276,10 +285,6 @@ class MainConfig:
 
     nodeID = os.environ.get('FTS_NODE_ID', f"FreeTAKServer-{id}")
 
-    # set to None if you don't want a message sent
-    ConnectionMessage = f'Welcome to FreeTAKServer {version}. The Parrot is not dead. It’s just resting'
-
-
     # location to backup client packages
     clientPackages = str(Path(fr'{MainPath}/certs/ClientPackages'))
 
