@@ -1,3 +1,4 @@
+from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModel.Filename import Filename
 from FreeTAKServer.model.FTSModel.Hash import Hash
 from FreeTAKServer.model.FTSModel.Keywords import Keywords
@@ -9,7 +10,7 @@ from FreeTAKServer.model.FTSModel.Submitter import Submitter
 from FreeTAKServer.model.FTSModel.Tool import Tool
 from FreeTAKServer.model.FTSModel.Uid import Uid
 
-class ContentResource:
+class ContentResource(FTSProtocolObject):
 
     def __init__(self):
         pass
